#[non_exhaustive]pub struct CreatePreparedStatementInput {
pub statement_name: Option<String>,
pub work_group: Option<String>,
pub query_statement: Option<String>,
pub description: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.statement_name: Option<String>The name of the prepared statement.
work_group: Option<String>The name of the workgroup to which the prepared statement belongs.
query_statement: Option<String>The query string for the prepared statement.
description: Option<String>The description of the prepared statement.
Implementations
Sourceimpl CreatePreparedStatementInput
impl CreatePreparedStatementInput
Sourcepub fn statement_name(&self) -> Option<&str>
pub fn statement_name(&self) -> Option<&str>
The name of the prepared statement.
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The name of the workgroup to which the prepared statement belongs.
Sourcepub fn query_statement(&self) -> Option<&str>
pub fn query_statement(&self) -> Option<&str>
The query string for the prepared statement.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the prepared statement.
Sourceimpl CreatePreparedStatementInput
impl CreatePreparedStatementInput
Sourcepub fn builder() -> CreatePreparedStatementInputBuilder
pub fn builder() -> CreatePreparedStatementInputBuilder
Creates a new builder-style object to manufacture CreatePreparedStatementInput.